Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6228)

Unified Diff: chrome/browser/banners/app_banner_manager_browsertest.cc

Issue 2951763003: Implement experimental app banner flow.
Patch Set: Browser test compile Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/banners/app_banner_manager.cc ('k') | chrome/browser/banners/app_banner_manager_desktop.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/banners/app_banner_manager_browsertest.cc
diff --git a/chrome/browser/banners/app_banner_manager_browsertest.cc b/chrome/browser/banners/app_banner_manager_browsertest.cc
index 4f014568e351a0d87b4934340dff02a7921bca5e..55d932f2c827e979073199e9c27c4d2d6f927113 100644
--- a/chrome/browser/banners/app_banner_manager_browsertest.cc
+++ b/chrome/browser/banners/app_banner_manager_browsertest.cc
@@ -71,8 +71,8 @@ class AppBannerManagerTest : public AppBannerManager {
protected:
// All calls to RequestAppBanner should terminate in one of Stop() (not
// showing banner), UpdateState(State::PENDING_ENGAGEMENT) (waiting for
// sufficient engagement), or ShowBanner(). Override these methods to capture
// test status.
void Stop() override {
AppBannerManager::Stop();
ASSERT_FALSE(will_show_.get());
@@ -80,7 +80,7 @@ class AppBannerManagerTest : public AppBannerManager {
base::ThreadTaskRunnerHandle::Get()->PostTask(FROM_HERE, quit_closure_);
}
- void ShowBanner() override {
+ void ShowBannerUI() override {
// Fake the call to ReportStatus here - this is usually called in
// platform-specific code which is not exposed here.
ReportStatus(nullptr, SHOWING_WEB_APP_BANNER);
@@ -71,8 +71,8 @@ class AppBannerManagerTest : public AppBannerManager {
// All calls to RequestAppBanner should terminate in one of Stop() (not
// showing banner), UpdateState(State::PENDING_ENGAGEMENT) (waiting for
- // sufficient engagement), or ShowBanner(). Override these methods to capture
- // test status.
+ // sufficient engagement), or ShowBannerUI(). Override these methods to
+ // capture test status.
void Stop() override {
AppBannerManager::Stop();
« no previous file with comments | « chrome/browser/banners/app_banner_manager.cc ('k') | chrome/browser/banners/app_banner_manager_desktop.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698